@@ -1,5 +1,5 @@
 /*
-	Copyright (C) 1995	Edward Der-Hua Liu, Hsin-Chu, Taiwan
+	Copyright (C) 1995-2008	Edward Der-Hua Liu, Hsin-Chu, Taiwan
 */
 typedef u_short phokey_t;
 
@@ -23,6 +23,12 @@ typedef struct {
   u_short start;
 } PHO_IDX;
 
+
+typedef struct {
+  char pinyin[6];
+  phokey_t key;
+} PIN_JUYIN;
+
 extern int start_idx, stop_idx;
 
 #define MAX_PHRASE_LEN (16)
@@ -38,6 +44,8 @@ extern PHO_IDX *idx_pho;
 extern int ch_pho_ofs;
 extern PHO_ITEM *ch_pho;
 extern int ch_phoN;
+extern PIN_JUYIN *pin_juyin;
+extern int pin_juyinN;
 
 void pho_load();
 extern char *pho_chars[];
@@ -45,8 +53,10 @@ char *phokey_to_str(phokey_t kk);
 int utf8_pho_keys(char *big5, phokey_t *phkeys);
 void prph(phokey_t kk);
 phokey_t pho2key(char typ_pho[]);
-gboolean save_phrase_to_db(phokey_t *phkeys, char *utf8str, int len, int usecount);
+gboolean save_phrase_to_db(phokey_t *phkeys, char *utf8str, int len, usecount_t usecount);
 int lookup(u_char *s);
+int find_match(char *str, int len, int *eq_N, usecount_t *usecount);
+
 
 #define MAX_PH_BF (90)
 
@@ -56,3 +66,5 @@ int lookup(u_char *s);
 #define TSIN_HASH_SHIFT 6
 
 #define PHO_CHAR_LEN 3
+
+#define BACK_QUOTE_NO 24
